# mash (mProv Admin Shell)

This is the command line utility for talking to the mProv Control Center.  

## Requirements
The `mash` requires python 3.8 and above.  It also requires that the packages in the `requirements.txt` be installed.  As always, you can accomplish this with the following pip command: `pip install -r requirements.txt`

